# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from landing_page_server_connector.models.landing_script import LandingScript  # noqa: E501

class TestLandingScript(unittest.TestCase):
    """LandingScript unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LandingScript:
        """Test LandingScript
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LandingScript`
        """
        model = LandingScript()  # noqa: E501
        if include_optional:
            return LandingScript(
                elements = [
                    landing_page_server_connector.models.script_element.ScriptElement(
                        tag = '', 
                        content = '', 
                        src = '', 
                        href = '', 
                        rel = '', )
                    ],
                title = '',
                category = 'analytics',
                placement = 'body'
            )
        else:
            return LandingScript(
                elements = [
                    landing_page_server_connector.models.script_element.ScriptElement(
                        tag = '', 
                        content = '', 
                        src = '', 
                        href = '', 
                        rel = '', )
                    ],
                title = '',
                category = 'analytics',
                placement = 'body',
        )
        """

    def testLandingScript(self):
        """Test LandingScript"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
